Enum ResetDirective
enum ResetDirective
What kind of context reset should be applied.
Variants
-
SessionOnly Only the session will be reset.
All parameters will be preserved (including the dictionary). But any frame being processed will be dropped.
It can be useful to start re-using a context after an error or when an ongoing compression is no longer needed.
-
Parameters Only reset parameters (including dictionary or referenced prefix).
All parameters will be reset to default values.
This can only be done between sessions - no compression or decompression must be ongoing.
-
SessionAndParameters Reset both the session and parameters.
The result is similar to a newly created context.
Implementations
impl Freeze for ResetDirective
impl RefUnwindSafe for ResetDirective
impl Send for ResetDirective
impl Sync for ResetDirective
impl Unpin for ResetDirective
impl UnsafeUnpin for ResetDirective
impl UnwindSafe for ResetDirective
impl<T> Any for ResetDirective
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for ResetDirective
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for ResetDirective
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for ResetDirective
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for ResetDirective
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for ResetDirective
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for ResetDirective
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>