Function create_ddict
fn create_ddict(dict_buffer: &[u8]) -> DDict<'static>
Wraps the ZSTD_createDDict() function.
It copies the dictionary internally, so the resulting DDict is 'static.
create_ddictfn create_ddict(dict_buffer: &[u8]) -> DDict<'static>
Wraps the ZSTD_createDDict() function.
It copies the dictionary internally, so the resulting DDict is 'static.