Function get_dict_id_from_dict
fn get_dict_id_from_dict(dict: &[u8]) -> Option<NonZeroU32>
Wraps the ZSTD_getDictID_fromDict() function.
Returns None if the dictionary is not a valid zstd dictionary.
get_dict_id_from_dictfn get_dict_id_from_dict(dict: &[u8]) -> Option<NonZeroU32>
Wraps the ZSTD_getDictID_fromDict() function.
Returns None if the dictionary is not a valid zstd dictionary.