Function get_error_name
fn get_error_name(code: usize) -> &'static str
Returns the error string associated with an error code.
get_error_namefn get_error_name(code: usize) -> &'static str
Returns the error string associated with an error code.