Struct zstd_safe::ContentSizeError
source · pub struct ContentSizeError;Expand description
Indicates an error happened when parsing the frame content size.
The stream may be corrupted, or the given frame prefix was too small.
pub struct ContentSizeError;Indicates an error happened when parsing the frame content size.
The stream may be corrupted, or the given frame prefix was too small.