Struct DDict

struct DDict<'a>(_, _)

A digested decompression dictionary.

Implementations

impl DDict<'static>

fn create(dict_buffer: &[u8]) -> Self
fn try_create(dict_buffer: &[u8]) -> Option<Self>

impl<'a> DDict<'a>

fn sizeof(self: &Self) -> usize
fn get_dict_id(self: &Self) -> Option<NonZeroU32>

Returns the dictionary ID for this dict.

Returns None if this dictionary is empty or invalid.

impl<'a> Drop for DDict<'a>

fn drop(self: &mut Self)

impl<'a> Freeze for DDict<'a>

impl<'a> RefUnwindSafe for DDict<'a>

impl<'a> Send for DDict<'a>

impl<'a> Sync for DDict<'a>

impl<'a> Unpin for DDict<'a>

impl<'a> UnsafeUnpin for DDict<'a>

impl<'a> UnwindSafe for DDict<'a>

impl<T> Any for DDict<'a>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for DDict<'a>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for DDict<'a>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> From for DDict<'a>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T, U> Into for DDict<'a>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for DDict<'a>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for DDict<'a>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>