pub enum ResetDirective {
SessionOnly,
Parameters,
SessionAndParameters,
}Expand description
What kind of context reset should be applied.
Variants
SessionOnly
Only the session will be reset.
All parameters will be preserved (including the dictionary). But any frame being processed will be dropped.
It can be useful to start re-using a context after an error or when an ongoing compression is no longer needed.
Parameters
Only reset parameters (including dictionary or referenced prefix).
All parameters will be reset to default values.
This can only be done between sessions - no compression or decompression must be ongoing.
SessionAndParameters
Reset both the session and parameters.
The result is similar to a newly created context.