Struct CDict
struct CDict<'a>(_, _)
Compression dictionary.
Implementations
impl CDict<'static>
fn create(dict_buffer: &[u8], compression_level: CompressionLevel) -> SelfPrepare a dictionary to compress data.
This will make it easier for compression contexts to load this dictionary.
The dictionary content will be copied internally, and does not need to be kept around.
Panics
If loading this dictionary failed.
fn try_create(dict_buffer: &[u8], compression_level: CompressionLevel) -> Option<Self>Prepare a dictionary to compress data.
This will make it easier for compression contexts to load this dictionary.
The dictionary content will be copied internally, and does not need to be kept around.
impl<'a> CDict<'a>
fn sizeof(self: &Self) -> usizeReturns the current memory usage of this dictionary.
Note that this may change over time.
fn get_dict_id(self: &Self) -> Option<NonZeroU32>Returns the dictionary ID for this dict.
Returns
Noneif this dictionary is empty or invalid.
impl<'a> Drop for CDict<'a>
fn drop(self: &mut Self)
impl<'a> Freeze for CDict<'a>
impl<'a> RefUnwindSafe for CDict<'a>
impl<'a> Send for CDict<'a>
impl<'a> Sync for CDict<'a>
impl<'a> Unpin for CDict<'a>
impl<'a> UnsafeUnpin for CDict<'a>
impl<'a> UnwindSafe for CDict<'a>
impl<T> Any for CDict<'a>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for CDict<'a>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for CDict<'a>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for CDict<'a>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for CDict<'a>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for CDict<'a>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for CDict<'a>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>